/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JTransactionManager.java 572 2006-06-04 21:23:27Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.transaction;

import java.rmi.RemoteException;

import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.transaction.TransactionManager;

import org.objectweb.jotm.Current;
import org.objectweb.jotm.TransactionFactory;
import org.objectweb.jotm.TransactionFactoryImpl;

import org.objectweb.easybeans.log.JLog;
import org.objectweb.easybeans.log.JLogFactory;

/**
 * Allows to get a transaction manager.
 * @author Florent Benoit
 */
public final class JTransactionManager {

    /**
     * Logger.
     */
    private static JLog logger = JLogFactory.getLog(JTransactionManager.class);


    /**
     * Utility class, no public constructor.
     */
    private JTransactionManager() {

    }


    /**
     * Internal tm.
     */
    private static TransactionManager tm = null;

    /**
     * Allow to get a transaction manager.
     * @return a transaction manager.
     */
    public static synchronized TransactionManager getTransactionManager() {
        if (tm != null) {
            return tm;
        }

        //Check if there is a factory in the JNDI
        try {
            tm = (TransactionManager) new InitialContext().lookup("javax.transaction.UserTransaction");
        } catch (NamingException e1) {
            logger.debug("No TM found in the registry");
        }

        if (tm != null) {
            return tm;
        }

        TransactionFactory transactionFactory;
        try {
            transactionFactory = new TransactionFactoryImpl();
        } catch (RemoteException e) {
            throw new IllegalStateException("Cannot get transaction factory", e);
        }

        try {
            new InitialContext().rebind("TMFactory", transactionFactory);
        } catch (NamingException e) {
            throw new IllegalStateException("Cannot bind transaction factory", e);
        }

        tm = new Current(transactionFactory);
        try {
            new InitialContext().rebind("javax.transaction.UserTransaction", tm);
        } catch (NamingException e) {
            throw new IllegalStateException("Cannot bind user transaction", e);
        }
        return tm;
    }
}
