/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EBaseTimeoutCallbackEJB00.java 304 2006-04-03 12:33:40Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.ejbs.base;

import static org.testng.Assert.assertTrue;

import javax.annotation.Resource;
import javax.ejb.EJB;
import javax.ejb.Timeout;
import javax.ejb.Timer;
import javax.ejb.TimerService;

import org.objectweb.easybeans.tests.common.resources.Watcher;

/**
 * Used as base of beans to test timeout callback.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public class EBaseTimeoutCallbackEJB00 implements ItfTimeoutCallback00{

    /**
     * TimerService.
     */
    @Resource
    private TimerService ts;

    /**
     * Bean.
     */
    @EJB(name="ejb/bean", beanName="EJBInjectionBean")
    private ItfOneMethod01 bean;

    /**
     * Timeout callback that access the session context.
     * @param timer timer with information.
     */
    @Timeout
    public void timeout(final Timer timer) {
        try {
            // EJB Access
            assertTrue(bean.getBool());
        } catch (Exception e) {
            Watcher.getInstance().setException(e);
        }
    }

    /**
     * Starts a timer and when this timer ends the timeout callback method access an EJB.
     * @param duration timer duration
     */
    public void startTimer(final int duration){
        ts.createTimer(DURATION, "");
    }
}
