/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EBaseInternalCallbackOrder00.java 692 2006-06-20 09:17:57Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.ejbs.base.lifecallback;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import javax.ejb.SessionContext;

import org.objectweb.easybeans.log.JLog;
import org.objectweb.easybeans.log.JLogFactory;
import org.objectweb.easybeans.tests.common.ejbs.base.ItfCheck01;


/**
 * Tests the PostConstruct invocation order.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 *
 */
public class EBaseInternalCallbackOrder00 implements ItfCheck01{

    /**
     * Log helper.
     */
    private JLog logger = JLogFactory.getLog(EBaseInternalCallbackOrder00.class);

    /**
     * Shows if a post construct method was executed.
     */
    private boolean okPostConstruct00;

    /**
     * Session Context.
     */
    @Resource
    private SessionContext ctx;

    /**
     * PostConstruct callback.
     */
    @SuppressWarnings("unused")
    @PostConstruct
    private void postConstruct00(){
        logger.debug("PostConstruct Method.");
        if (ctx == null){
            throw new IllegalStateException("PostConstruct callback must be invoked after the dependency injection.");
        }
        okPostConstruct00 = true;
    }

    /**
     * Do nothing.
     * @throws Exception if a problem occurs.
     */
    public void check() throws Exception{
    }

    /**
     * Gets the postconstruct invocation state.
     * @return true if the postconstruct callback was invoked.
     */
    protected boolean isOKPostConstruct(){
        return okPostConstruct00;
    }

}
