/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: OperationLogger.java 692 2006-06-20 09:17:57Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.ejbs.entity.callbacklogger;

import java.text.MessageFormat;

import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.Table;

/**
 * Makes the log of the operations.
 * @author Gisele Pinheiro Souza
 * @author Eduardo Studzinski Estima de Castro
 */
@Entity
@Table(name = "OPERATIONLOGGER")
@DiscriminatorValue("operation")
public class OperationLogger extends CallbackLogger {

    /**
     * Class ID.
     */
    private static final long serialVersionUID = 6121867108408882235L;

    /**
     * The identifier of the operation.
     */
    private OperationType opType;

    /**
     * Gets the operation type.
     * @return the operation type.
     */
    @Enumerated(EnumType.STRING)
    public OperationType getOperationType() {
        return opType;
    }

    /**
     * Sets the operation type.
     * @param operationType the operation type.
     */
    public void setOperationType(final OperationType operationType) {
        this.opType = operationType;
    }

    /**
     * String representation of the object.
     * @return object representation
     */
    @SuppressWarnings("boxing")
    @Override
    public String toString() {
        return MessageFormat
                .format(
                        "{0}, ID = {1}, ClassName = {2}, CallbackClassName = {3}, CallbackEvent = {4}, "
                        + "OperationType = {5}, Date = {6}",
                        OperationLogger.class.getName(), getId(), getClassName(), getCallbackClassName(),
                        getCallbackEvent(), getOperationType(), getInsertionDate());
    }

}
