/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestSFAllCallbackOrder00.java 692 2006-06-20 09:17:57Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.interceptors.lifecycle.stateful.containermanaged;

import static org.objectweb.easybeans.tests.common.ejbs.entity.callbacklogger.CallbackType.POST_CONSTRUCT;
import static org.objectweb.easybeans.tests.common.ejbs.entity.callbacklogger.CallbackType.PRE_DESTROY;
import static org.objectweb.easybeans.tests.common.helper.EJBHelper.getBeanRemoteInstance;

import java.util.ArrayList;
import java.util.List;

import org.objectweb.easybeans.tests.common.ejbs.base.ItfCheck02;
import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.lifecallback.BasePostConstructAllOrder00;
import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.lifecallback.BasePreDestroyAllOrder00;
import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.lifecallback.SLSBPostConstructAllOrder;
import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.lifecallback.SLSBPreDestroyAllOrder;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.callbacklogger.ItfCallbackLoggerAccess;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.callbacklogger.SLSBCallbackLoggerAccess;
import org.objectweb.easybeans.tests.common.interceptors.lifecycle.postconstruct.PostConstructLogger00;
import org.objectweb.easybeans.tests.common.interceptors.lifecycle.postconstruct.PostConstructLogger01;
import org.objectweb.easybeans.tests.common.interceptors.lifecycle.predestroy.PreDestroyLogger00;
import org.objectweb.easybeans.tests.common.interceptors.lifecycle.predestroy.PreDestroyLogger01;
import org.testng.annotations.Configuration;
import org.testng.annotations.Test;


/**
 * Verifies if interceptors invocation order.
 * @reference JSR220-PROPOSED FINAL
 * @requirement Application Server must be running; the beans
 *              org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.lifecallback.*
 *              must be deployed.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public class TestSFAllCallbackOrder00 {

    /**
     * Sleep time.
     */
    public static final int SLEEP = 1000;

    /**
     * Bean.
     */
    private ItfCheck02 beanPostConstructAllOrder;

    /**
     * Bean.
     */
    private ItfCheck02 beanPreDestroyAllOrder;


    /**
     * Logger bean.
     */
    private ItfCallbackLoggerAccess beanLogger;

    /**
     * Gets bean instances used in the tests.
     * @throws Exception if there is a problem with the bean initialization.
     */
    @Configuration(beforeTestClass = true)
    public void startBeans() throws Exception {
        beanPostConstructAllOrder = getBeanRemoteInstance(SLSBPostConstructAllOrder.class, ItfCheck02.class);
        beanPreDestroyAllOrder = getBeanRemoteInstance(SLSBPreDestroyAllOrder.class, ItfCheck02.class);
    }

    /**
     * Gets bean instances used in the tests.
     * @throws Exception if there is a problem with the bean initialization.
     */
    @Configuration(beforeTestMethod = true)
    public void startLog() throws Exception {
        beanLogger = getBeanRemoteInstance(SLSBCallbackLoggerAccess.class, ItfCallbackLoggerAccess.class);
        beanLogger.deleteAll();
    }

    /**
     * Verifies if the PostConstruct callback in invoked in the correct order.
     * @input -
     * @output -
     * @throws Exception if a problem occurs.
     */
    @Test
    public void testPostConstruct() throws Exception {
        /*TODO: review after PostConstruct implementation.*/

        beanPostConstructAllOrder.check();

        //Interceptors list
        List<String> arLife = new ArrayList<String>();

        arLife.add(PostConstructLogger00.class.getName());
        arLife.add(PostConstructLogger01.class.getName());
        arLife.add(BasePostConstructAllOrder00.class.getName());
        arLife.add(SLSBPostConstructAllOrder.class.getName());

        beanLogger.verifyCallbackOrder(SLSBPostConstructAllOrder.class, POST_CONSTRUCT,
                arLife.toArray(new String[0]));
    }

    /**
     * Verifies if the PreDestroy callback in invoked in the correct order.
     * @input -
     * @output -
     * @throws Exception if a problem occurs.
     */
    @Test
    public void testPreDestroy() throws Exception {
        /*TODO: review after PreDestroy implementation.*/

        beanPreDestroyAllOrder.check();
        beanPreDestroyAllOrder.remove();

        //Wait interceptors execution
        Thread.sleep(SLEEP);

        //Interceptors list
        List<String> arLife = new ArrayList<String>();

        arLife.add(PreDestroyLogger00.class.getName());
        arLife.add(PreDestroyLogger01.class.getName());
        arLife.add(BasePreDestroyAllOrder00.class.getName());
        arLife.add(SLSBPreDestroyAllOrder.class.getName());

        beanLogger.verifyCallbackOrder(SLSBPreDestroyAllOrder.class, PRE_DESTROY,
                arLife.toArray(new String[0]));
    }

    /**
     * Clears callback event log.
     */
    @Configuration(afterTestMethod = true)
    public void tearDown(){
        beanLogger.deleteAll();
    }
}
