/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestSLPostConstruct00.java 692 2006-06-20 09:17:57Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.interceptors.lifecycle.stateless.containermanaged;

import static org.objectweb.easybeans.tests.common.helper.ExceptionHelper.checkCause;
import static org.objectweb.easybeans.tests.common.helper.EJBHelper.getBeanRemoteInstance;
import static org.testng.Assert.fail;

import javax.ejb.EJBException;

import org.objectweb.easybeans.tests.common.ejbs.base.ItfCheck00;
import org.objectweb.easybeans.tests.common.ejbs.base.ItfCheck01;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.lifecallback.SLSBPostConstructExternalOrder00;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.lifecallback.SLSBPostConstructExternalOrder01;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.lifecallback.SLSBPostConstructInternalOrder00;
import org.objectweb.easybeans.tests.common.exception.CallbackOKException;
import org.objectweb.easybeans.tests.common.exception.CatchedException;
import org.testng.annotations.Configuration;
import org.testng.annotations.Test;

/**
 * Verifies if interceptors invocation order.
 * @reference JSR220-PROPOSED FINAL - Table 2
 * @requirement Application Server must be running; the beans
 *              org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.lifecallback.*
 *              must be deployed.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public class TestSLPostConstruct00 {

    /**
     * Bean.
     */
    private ItfCheck00 bean00;

    /**
     * Bean.
     */
    private ItfCheck01 bean01;

    /**
     * Bean.
     */
    private ItfCheck00 bean02;

    /**
     * Gets bean instances used in the tests.
     * @throws Exception if there is a problem with the bean initialization.
     */
    @Configuration(beforeTestClass = true)
    public void startUp() throws Exception {
        bean00 = getBeanRemoteInstance(SLSBPostConstructExternalOrder00.class, ItfCheck00.class);
        bean01 = getBeanRemoteInstance(SLSBPostConstructInternalOrder00.class, ItfCheck01.class);
        bean02 = getBeanRemoteInstance(SLSBPostConstructExternalOrder01.class, ItfCheck00.class);
    }

    /**
     * Verifies if the post construct callback in invoked in the correct order.
     * The bean contains two interceptors that one throw an exception and the
     * other must catch, the last must throw a new exception that is expected by
     * the test.
     * @input -
     * @output CatchedException
     * @throws Exception if a problem occurs.
     */
    @Test
    public void test00() throws Exception {
        try {
            bean00.check();
            fail("The interceptors must throw an exception.");
        } catch (EJBException e) {
            checkCause(e, CatchedException.class);
        }
    }

    /**
     * Verifies if the post construct callback in invoked in the correct order.
     * The bean contains an interceptor inside the bean class that throws an
     * exception.
     * @input -
     * @output CustomException00
     * @throws Exception if a problem occurs.
     */
    @Test
    public void test01() throws Exception {
        try {
            bean01.check();
            fail("The interceptors must throw an exception.");
        } catch (Exception e) {
            checkCause(e, CallbackOKException.class);
        }
    }

    /**
     * Verifies if the postconstruct callback in invoked in the correct order.
     * The bean contains an interceptor class
     * @input -
     * @output CatchedException
     * @throws Exception if a problem occurs.
     */
    @Test
    public void test02() throws Exception {
        try {
            bean02.check();
            fail("The interceptors must throw an exception.");
        } catch (EJBException e) {
            checkCause(e, CatchedException.class);
        }
    }
}
