/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestMandatoryRemoteSFSB.java 364 2006-04-20 11:41:05Z pinheirg $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.transaction.containermanaged.stateful;

import java.sql.SQLException;

import javax.ejb.EJBTransactionRequiredException;

import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SFSBContainerTransactionMandatory;
import org.objectweb.easybeans.tests.transaction.containermanaged.base.TestMandatory;
import org.testng.annotations.Configuration;
import org.testng.annotations.ExpectedExceptions;
import org.testng.annotations.Test;

/**
 * Verifies if the container-managed transaction in the stateful bean is
 * following the JSR220.The items covered in this test are: 12.6.2.5.
 * @reference JSR220-PROPOSED FINAL
 * @requirement Application Server must be running; the bean
 *              org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SFSBContainerTransactionMandatory
 *              must be deployed.
 * @setup gets the reference of SFSBContainerTransactionMandatory and binds the
 *        databases specified in the EmbeddedTest.
 * @author Gisele Pinheiro Souza
 * @author Eduardo Studzinski Estima de Castro
 */
public class TestMandatoryRemoteSFSB extends TestMandatory {


    /**
     * Creates a new instance of the bean.
     * @throws Exception if a lookup error occurs.
     */
    @Configuration(beforeTestMethod = true)
    public void createBean() throws Exception {
        super.createBean(SFSBContainerTransactionMandatory.class);
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestMandatory
     * @throws Exception if an error during the test startup occurs.
     */
    @Configuration(beforeTestClass = true)
    @Override
    public void setup() throws Exception {
        super.setup();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestMandatory
     * @throws Exception if an error during the tests occurs.
     */
    @Test(groups = {"mandatory attribute features"}, alwaysRun = true)
    @Override
    @ExpectedExceptions(value = SQLException.class)
    public void testUsingClientTrans() throws Exception {
        super.testUsingClientTrans();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestMandatory
     * @throws Exception if an error occurs during the tests.
     */
    @Test(groups = {"rollback"})
    @Override
    @ExpectedExceptions(value = SQLException.class)
    public void testSetRollbackOnlyWithUserTransaction() throws Exception {
         super.testSetRollbackOnlyWithUserTransaction();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestMandatory
     * @throws Exception if an error occurs during the tests.
     */
    @Test(groups = {"rollback"})
    @Override
    @ExpectedExceptions(value = EJBTransactionRequiredException.class)
    public void testSetRollbackOnlyWithoutUserTransaction() throws Exception {
         super.testSetRollbackOnlyWithoutUserTransaction();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestMandatory
     * @throws Exception if an error occurs during the tests.
     */
    @Test(groups = {"rollback"})
    @Override
    public void testGetRollbackOnlyWithUserTransaction() throws Exception {
         super.testGetRollbackOnlyWithUserTransaction();

    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestMandatory
     * @throws Exception if an error occurs during the tests.
     */
    @Test(groups = {"rollback"})
    @Override
    @ExpectedExceptions(value = EJBTransactionRequiredException.class)
    public void testGetRollbackOnlyWithoutUserTransaction() throws Exception {
         super.testGetRollbackOnlyWithoutUserTransaction();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestMandatory
     */
    @Configuration(beforeTestMethod = true)
    @Override
    public void deleteTable() {
        super.deleteTable();
    }

    /**
     * Makes a rollback in the transaction actives.
     * @throws Exception if a transaction exception occurs.
     */
    @Configuration(beforeTestMethod = true)
    @Override
    public void cleanTransaction() throws Exception{
        super.cleanTransaction();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestMandatory
     * @throws if an error during the tests occurs.
     */
    @Test(groups = {"general attribute features"})
    @Override
    @ExpectedExceptions(value = java.lang.IllegalStateException.class)
    public void testGetUserTransactionWithEJBContext() throws Exception {
        super.testGetUserTransactionWithEJBContext();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestMandatory
     * @throws if an error during the tests occurs.
     */
    @Test(groups = {"general attribute features"})
    @Override
    @ExpectedExceptions(value = javax.naming.NameNotFoundException.class)
    public void testGetUserTransactionWithLookup() throws Exception {
        super.testGetUserTransactionWithLookup();
    }
}
