/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestSupportsExceptionRemoteSFSB.java 439 2006-05-10 11:21:09Z pinheirg $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.transaction.containermanaged.stateful;

import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SFSBContainerTransactionSupportsApp;
import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SFSBContainerTransactionSupportsRollback;
import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SFSBContainerTransactionSupportsRuntime;
import org.objectweb.easybeans.tests.transaction.containermanaged.base.TestSupportsException;
import org.testng.annotations.Configuration;
import org.testng.annotations.Test;


/**
 * Verifies if the container-managed transaction in the session bean is
 * following the JSR220. The container must handle the different types of
 * exception in the transaction context. The items covered in this test are:
 * 13.3
 * @reference JSR220-PROPOSED FINAL
 * @requirement Application Server must be running; the bean .
 *              SFSBContainerTransactionSupportsNewApp,
 *              SFSBContainerTransactionSupportsNewRollback and
 *              SFSBContainerTransactionSupportsNewRuntime must be deployed for
 *              testing stateful session bean.
 * @setup gets the reference of the bean and binds the databases specified in
 *        the EmbeddedTest.
 * @author Gisele Pinheiro Souza
 * @author Eduardo Studzinski Estima de Castro
 */
public class TestSupportsExceptionRemoteSFSB extends TestSupportsException {

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestSupportsException
     * @throws Exception if an error during the initialization occurs.
     */
    @Test(groups = {"runtime exception tests"})
    @Override
    public void testCallOtherBeanNotSupWithoutTrans() throws Exception {
        super.testCallOtherBeanNotSupWithoutTrans();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestSupportsException
     * @throws Exception if an error during the initialization occurs.
     */
    @Test(groups = {"runtime exception tests"})
    @Override
    public void testCallOtherBeanNotSupWithTrans() throws Exception {
        super.testCallOtherBeanNotSupWithTrans();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestSupportsException
     * @throws Exception if an error during the initialization occurs.
     */
    @Test(groups = {"runtime exception tests"})
    @Override
    public void testCallOtherBeanReqWithoutTrans() throws Exception {
        super.testCallOtherBeanReqWithoutTrans();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestSupportsException
     * @throws Exception if an error during the initialization occurs.
     */
    @Test(groups = {"runtime exception tests"})
    @Override
    public void testCallOtherBeanReqWithTrans() throws Exception {
        super.testCallOtherBeanReqWithTrans();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestContainerTransactionException
     * @throws Exception if an error during the initialization occurs.
     */
    @Test(groups = {"application exception tests"})
    @Override
    public void testNotUsingClientTransWithAppException() throws Exception {
        super.testNotUsingClientTransWithAppException();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestContainerTransactionException
     * @throws Exception if an error during the initialization occurs.
     */
    @Test(groups = {"application rollback exception tests"})
    @Override
    public void testNotUsingClientTransWithAppRollbackException() throws Exception {
        super.testNotUsingClientTransWithAppRollbackException();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestContainerTransactionException
     * @throws Exception if an error during the initialization occurs.
     */
    @Test(groups = {"runtime exception tests"})
    @Override
    public void testNotUsingClientTransWithRuntimeException() throws Exception {
        super.testNotUsingClientTransWithRuntimeException();
    }

    /**
     * Creates a bean used during the tests before each test.
     * @throws Exception if a lookup error occurs.
     */
    @Configuration(beforeTestMethod = true, groups = "application exception tests")
    public void createBeanApp() throws Exception {
        super.createBeanApp(SFSBContainerTransactionSupportsApp.class);
    }

    /**
     * Creates a bean used during the tests before each test.
     * @throws Exception if a lookup error occurs.
     */
    @Configuration(beforeTestMethod = true, groups = "application rollback exception tests")
    public void createBeanRollback() throws Exception {
        super.createBeanRollback(SFSBContainerTransactionSupportsRollback.class);
    }

    /**
     * Creates a bean used during the tests before each test.
     * @throws Exception if a lookup error occurs.
     */
    @Configuration(beforeTestMethod = true, groups = "runtime exception tests")
    public void createBeanRuntime() throws Exception {
        super.createBeanRuntime(SFSBContainerTransactionSupportsRuntime.class);
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestContainerTransactionException
     */
    @Configuration(beforeTestMethod = true)
    @Override
    public void deleteTable() {
        super.deleteTable();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestContainerTransactionException
     * @throws Exception if an error during the initialization occurs.
     */
    @Configuration(beforeTestClass = true)
    @Override
    public void setup() throws Exception {
        super.setup();
    }

    /**
     * Cleans the transaction actives before each test.
     * @throws Exception if the transaction cannot be closed.
     */
    @Configuration(beforeTestMethod = true)
    @Override
    public void cleanTransaction() throws Exception {
         super.cleanTransaction();
    }

}
